#!/bin/sh
#
# Driver program to make manual pages, using manify.awk and pandoc.
#

MANIFY_SCRIPT=`dirname $0`/manify.awk
RUN_MANIFY="gawk -f $MANIFY_SCRIPT"
SECTION=3

# sanity check
if ! test -f $MANIFY_SCRIPT
then
    echo "Cannot find manify.awk!"
    exit 1
fi

tmp=,,manify.tmp.$$
if test -f $tmp
then
    echo "$tmp already exists!"
    exit 1
fi
cleanup() {
    exitcode=$?
    rm -f "$tmp"
    exit $exitcode
}
trap cleanup 0 1 2 3 13 15

for input in "$@"
do
    output=`basename $input | sed 's/[.].*//'`.$SECTION

    # sanity check
    if test $input = $output
    then
	echo "Skipping $input"
	continue
    fi

    (
	$RUN_MANIFY $input > $tmp &&
	pandoc $tmp --standalone -t man -o $output 
    ) || exit 1
done
