#!/usr/bin/gawk -f
#
# This script takes a Pandoc file in a very format and produces another Pandoc
# file that can then be used to generate a man page.  The format is:
#
#-----------------------------------------------------------------------------
#     ### my_function
#
#         int my_function(void)
#
#     The description goes here.
#
#     *Return value:*
#
#     Describe the return value.
#
#     *See also:*
#     [my_other_function].
#-----------------------------------------------------------------------------
#
# All [links] are replaced by man page references, e.g. my_other_function(3).
#
#-----------------------------------------------------------------------------

BEGIN {
   # constants
   MANUAL = "Allegro manual"
   VERSION = "Version 4.9.3 (SVN)"
   SECTION = 3

   seen_name = 0
   seen_synopsis = 0
   seen_description = 0
}

/^#+ / {
   if (! seen_name) {
      print "% " $2 "(" SECTION ") " VERSION " | " MANUAL
      print "\n# NAME"
      print $2
      seen_name = 1
   }
   next
}

/^    / {
   if (! seen_synopsis) {
      print "\n# SYNOPSIS"
      seen_synopsis = 1
   }
   sub(/^ */, "")    # delete initial whitespace
   print $0
   next
}

/^[*]Return value:[*]/ {
   print "\n# RETURN VALUE"
   next
}

/^[*]See also:[*]/ {
   print "\n# SEE ALSO"
   next
}

{
   if (! seen_synopsis) {
      next
   }

   if (! seen_description) {
      print "\n# DESCRIPTION"
      seen_description = 1
   }

   # Replace all [ref] by man page references.
   # This uses a GNU awk extension.
   print gensub("\\[([^]]+)\\]", "\\1(" SECTION ")", "1")
}

# vi: set sts=3 sw=3 et:
